# coding: utf-8

# flake8: noqa
"""
    UniCatDB API

    UniCatDB application API documentation, with examples and live testing.  This API is built in accordance with the **JSON API 1.0 standard**. For general information, see [the documentation](http://jsonapi.org/format/).  **Notes:** * JSON API standard requires use of the JSON API media type (application/vnd.api+json) for exchanging data. Clients must send all JSON API data with the headers `Content-Type: application/vnd.api+json` (POST, PATCH) and `Accept: application/vnd.api+json` (GET, DELETE). * [Relationships](http://jsonapi.org/format/#fetching-relationships) and their [inclusions](http://jsonapi.org/format/#fetching-includes) via the `include` query parameter, as specified by the standard, **are not implemented**, since there are no relationships present in the data model. * The standard does not prescribe any filtering strategies. This API implements two strategies which can be combined: **Basic filtering** based on the used [JSON API library](https://json-api-dotnet.github.io/#/filtering) and **Custom filtering** which allow for any possible query to the MongoDB server and can be extended and customize in the future. For more information about filtering, see the description of the `filter` down bellow. * **Non-standard PATCH behavior:** Sucessfull PATCH reuest always result in HTTP 200 response with the updated resource object, even if the server does not perform any additional modifications. HTTP 204 is never used in PATCH responses.   # noqa: E501

    The version of the OpenAPI document: v2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from unicatdb.openapi_client.models.attachment import Attachment
from unicatdb.openapi_client.models.attachment_array_response import AttachmentArrayResponse
from unicatdb.openapi_client.models.attachment_fields_query import AttachmentFieldsQuery
from unicatdb.openapi_client.models.attachment_put_response import AttachmentPutResponse
from unicatdb.openapi_client.models.attachment_resource_object import AttachmentResourceObject
from unicatdb.openapi_client.models.attachment_resource_object_relationships import AttachmentResourceObjectRelationships
from unicatdb.openapi_client.models.attachment_single_response import AttachmentSingleResponse
from unicatdb.openapi_client.models.error_response import ErrorResponse
from unicatdb.openapi_client.models.error_response_item import ErrorResponseItem
from unicatdb.openapi_client.models.existing_finding_request_body import ExistingFindingRequestBody
from unicatdb.openapi_client.models.existing_finding_schema_request_body import ExistingFindingSchemaRequestBody
from unicatdb.openapi_client.models.existing_tenant_request_body import ExistingTenantRequestBody
from unicatdb.openapi_client.models.existing_tenant_user_request_body import ExistingTenantUserRequestBody
from unicatdb.openapi_client.models.finding import Finding
from unicatdb.openapi_client.models.finding_array_response import FindingArrayResponse
from unicatdb.openapi_client.models.finding_fields_query import FindingFieldsQuery
from unicatdb.openapi_client.models.finding_resource_object import FindingResourceObject
from unicatdb.openapi_client.models.finding_resource_object_relationships import FindingResourceObjectRelationships
from unicatdb.openapi_client.models.finding_schema import FindingSchema
from unicatdb.openapi_client.models.finding_schema_array_response import FindingSchemaArrayResponse
from unicatdb.openapi_client.models.finding_schema_definition_group import FindingSchemaDefinitionGroup
from unicatdb.openapi_client.models.finding_schema_element import FindingSchemaElement
from unicatdb.openapi_client.models.finding_schema_element_value import FindingSchemaElementValue
from unicatdb.openapi_client.models.finding_schema_fields_query import FindingSchemaFieldsQuery
from unicatdb.openapi_client.models.finding_schema_resource_object import FindingSchemaResourceObject
from unicatdb.openapi_client.models.finding_schema_resource_object_relationships import FindingSchemaResourceObjectRelationships
from unicatdb.openapi_client.models.finding_schema_single_response import FindingSchemaSingleResponse
from unicatdb.openapi_client.models.finding_single_response import FindingSingleResponse
from unicatdb.openapi_client.models.frequency_chart import FrequencyChart
from unicatdb.openapi_client.models.frequency_chart_item import FrequencyChartItem
from unicatdb.openapi_client.models.invitation import Invitation
from unicatdb.openapi_client.models.lat_lng_gps import LatLngGps
from unicatdb.openapi_client.models.level_description_element import LevelDescriptionElement
from unicatdb.openapi_client.models.mini_map_data import MiniMapData
from unicatdb.openapi_client.models.mini_map_data_item import MiniMapDataItem
from unicatdb.openapi_client.models.new_finding_request_body import NewFindingRequestBody
from unicatdb.openapi_client.models.new_finding_schema_request_body import NewFindingSchemaRequestBody
from unicatdb.openapi_client.models.new_invitation_request_body import NewInvitationRequestBody
from unicatdb.openapi_client.models.new_tenant_request_body import NewTenantRequestBody
from unicatdb.openapi_client.models.page_query import PageQuery
from unicatdb.openapi_client.models.relationship_links import RelationshipLinks
from unicatdb.openapi_client.models.relationship_resource_identifier import RelationshipResourceIdentifier
from unicatdb.openapi_client.models.relationship_resource_identifier_array_response import RelationshipResourceIdentifierArrayResponse
from unicatdb.openapi_client.models.relationship_resource_identifier_response import RelationshipResourceIdentifierResponse
from unicatdb.openapi_client.models.response_links import ResponseLinks
from unicatdb.openapi_client.models.response_meta import ResponseMeta
from unicatdb.openapi_client.models.response_relationship_one_to_many import ResponseRelationshipOneToMany
from unicatdb.openapi_client.models.response_relationship_one_to_one import ResponseRelationshipOneToOne
from unicatdb.openapi_client.models.statistical_data import StatisticalData
from unicatdb.openapi_client.models.statistical_data_item import StatisticalDataItem
from unicatdb.openapi_client.models.statistical_data_meta import StatisticalDataMeta
from unicatdb.openapi_client.models.taxonomy_name import TaxonomyName
from unicatdb.openapi_client.models.taxonomy_node import TaxonomyNode
from unicatdb.openapi_client.models.taxonomy_tree import TaxonomyTree
from unicatdb.openapi_client.models.tenant import Tenant
from unicatdb.openapi_client.models.tenant_invitee_role import TenantInviteeRole
from unicatdb.openapi_client.models.tenant_user import TenantUser
from unicatdb.openapi_client.models.tenant_user_role import TenantUserRole
from unicatdb.openapi_client.models.user_scoped_tenant import UserScopedTenant



from .openapi_client import FindingsApi, ApiClient, ChartsApi, AttachmentsApi, SchemasApi, TenantsApi, ExportApi
from . import Configuration


class Client():

    def __init__(self, configuration: Configuration) -> None:
        super().__init__()

        self.__configured_api_client = ApiClient(configuration)

    # support for with() statement
    def __enter__(self):
        self.__configured_api_client.__enter__()
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        self.__configured_api_client.__exit__(exc_type, exc_value, traceback)

    def close(self):
        self.__configured_api_client.close()

    # individual APIs as configured properties:

    @property
    def attachments(self):
        return AttachmentsApi(self.__configured_api_client)

    @property
    def charts(self):
        return ChartsApi(self.__configured_api_client)

    @property
    def export(self):
        return ExportApi(self.__configured_api_client)

    @property
    def findings(self):
        return FindingsApi(self.__configured_api_client)

    @property
    def schemas(self):
        return SchemasApi(self.__configured_api_client)

    @property
    def tenants(self):
        return TenantsApi(self.__configured_api_client)



# coding: utf-8

"""
    UniCatDB API

    UniCatDB application API documentation, with examples and live testing.  This API is built in accordance with the **JSON API 1.0 standard**. For general information, see [the documentation](http://jsonapi.org/format/).  **Notes:** * JSON API standard requires use of the JSON API media type (application/vnd.api+json) for exchanging data. Clients must send all JSON API data with the headers `Content-Type: application/vnd.api+json` (POST, PATCH) and `Accept: application/vnd.api+json` (GET, DELETE). * [Relationships](http://jsonapi.org/format/#fetching-relationships) and their [inclusions](http://jsonapi.org/format/#fetching-includes) via the `include` query parameter, as specified by the standard, **are not implemented**, since there are no relationships present in the data model. * The standard does not prescribe any filtering strategies. This API implements two strategies which can be combined: **Basic filtering** based on the used [JSON API library](https://json-api-dotnet.github.io/#/filtering) and **Custom filtering** which allow for any possible query to the MongoDB server and can be extended and customize in the future. For more information about filtering, see the description of the `filter` down bellow. * **Non-standard PATCH behavior:** Sucessfull PATCH reuest always result in HTTP 200 response with the updated resource object, even if the server does not perform any additional modifications. HTTP 204 is never used in PATCH responses.   # noqa: E501

    The version of the OpenAPI document: v2
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from unicatdb.openapi_client.configuration import Configuration


class Invitation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'tenant': 'Tenant',
        'inviter': 'TenantUser',
        'created_at': 'datetime',
        'expires_at': 'datetime',
        'invitee_role': 'TenantInviteeRole',
        'key': 'str'
    }

    attribute_map = {
        'id': 'id',
        'tenant': 'tenant',
        'inviter': 'inviter',
        'created_at': 'createdAt',
        'expires_at': 'expiresAt',
        'invitee_role': 'inviteeRole',
        'key': 'key'
    }

    def __init__(self, id=None, tenant=None, inviter=None, created_at=None, expires_at=None, invitee_role=None, key=None, local_vars_configuration=None):  # noqa: E501
        """Invitation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._tenant = None
        self._inviter = None
        self._created_at = None
        self._expires_at = None
        self._invitee_role = None
        self._key = None
        self.discriminator = None

        self.id = id
        self.tenant = tenant
        self.inviter = inviter
        self.created_at = created_at
        self.expires_at = expires_at
        self.invitee_role = invitee_role
        self.key = key

    @property
    def id(self):
        """Gets the id of this Invitation.  # noqa: E501

        Invitation ID  # noqa: E501

        :return: The id of this Invitation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Invitation.

        Invitation ID  # noqa: E501

        :param id: The id of this Invitation.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def tenant(self):
        """Gets the tenant of this Invitation.  # noqa: E501


        :return: The tenant of this Invitation.  # noqa: E501
        :rtype: Tenant
        """
        return self._tenant

    @tenant.setter
    def tenant(self, tenant):
        """Sets the tenant of this Invitation.


        :param tenant: The tenant of this Invitation.  # noqa: E501
        :type tenant: Tenant
        """
        if self.local_vars_configuration.client_side_validation and tenant is None:  # noqa: E501
            raise ValueError("Invalid value for `tenant`, must not be `None`")  # noqa: E501

        self._tenant = tenant

    @property
    def inviter(self):
        """Gets the inviter of this Invitation.  # noqa: E501


        :return: The inviter of this Invitation.  # noqa: E501
        :rtype: TenantUser
        """
        return self._inviter

    @inviter.setter
    def inviter(self, inviter):
        """Sets the inviter of this Invitation.


        :param inviter: The inviter of this Invitation.  # noqa: E501
        :type inviter: TenantUser
        """
        if self.local_vars_configuration.client_side_validation and inviter is None:  # noqa: E501
            raise ValueError("Invalid value for `inviter`, must not be `None`")  # noqa: E501

        self._inviter = inviter

    @property
    def created_at(self):
        """Gets the created_at of this Invitation.  # noqa: E501

        Timestamp when the invitation was created.  # noqa: E501

        :return: The created_at of this Invitation.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Invitation.

        Timestamp when the invitation was created.  # noqa: E501

        :param created_at: The created_at of this Invitation.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def expires_at(self):
        """Gets the expires_at of this Invitation.  # noqa: E501

        Timestamp when the invitation expires, cannot be redeemed after.  # noqa: E501

        :return: The expires_at of this Invitation.  # noqa: E501
        :rtype: datetime
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this Invitation.

        Timestamp when the invitation expires, cannot be redeemed after.  # noqa: E501

        :param expires_at: The expires_at of this Invitation.  # noqa: E501
        :type expires_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and expires_at is None:  # noqa: E501
            raise ValueError("Invalid value for `expires_at`, must not be `None`")  # noqa: E501

        self._expires_at = expires_at

    @property
    def invitee_role(self):
        """Gets the invitee_role of this Invitation.  # noqa: E501


        :return: The invitee_role of this Invitation.  # noqa: E501
        :rtype: TenantInviteeRole
        """
        return self._invitee_role

    @invitee_role.setter
    def invitee_role(self, invitee_role):
        """Sets the invitee_role of this Invitation.


        :param invitee_role: The invitee_role of this Invitation.  # noqa: E501
        :type invitee_role: TenantInviteeRole
        """
        if self.local_vars_configuration.client_side_validation and invitee_role is None:  # noqa: E501
            raise ValueError("Invalid value for `invitee_role`, must not be `None`")  # noqa: E501

        self._invitee_role = invitee_role

    @property
    def key(self):
        """Gets the key of this Invitation.  # noqa: E501

        Access key used in redeeming process.  # noqa: E501

        :return: The key of this Invitation.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this Invitation.

        Access key used in redeeming process.  # noqa: E501

        :param key: The key of this Invitation.  # noqa: E501
        :type key: str
        """
        if self.local_vars_configuration.client_side_validation and key is None:  # noqa: E501
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501

        self._key = key

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Invitation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Invitation):
            return True

        return self.to_dict() != other.to_dict()



from . import openapi_client
from .servers import Servers


class Configuration(openapi_client.Configuration):

    def __init__(self, access_token=None, server: Servers = Servers.UNICATDB_ORG):
        self.access_token = access_token
        super().__init__(host=server.value)



from setuptools import setup, find_packages

# read the contents of your README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

with open(path.join(this_directory, 'VERSION'), encoding='utf-8') as f:
    version = f.read()
    # remove all whitespace
    version = "".join(version.split())

setup(
    name = 'unicatdb',         # How you named your package folder (MyLib)
    packages = find_packages(),   # Chose the same as "name"
    version = version,      # Start with a small number and increase it with every change you make
    license='All rights reserved',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description = 'Python library for accessing API of the UniCatDB - Universal Catalog Database for biological findings.',   # Give a short description about your library
    author = 'Ondřej Doktor',                   # Type in your name
    author_email = 'doktoo00@jcu.cz',      # Type in your E-Mail
    url = 'https://unicatdb.org',   # Provide either the link to your github or to your website
    # download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
    keywords = ['UniCatDB', 'API', 'Universal Catalog Database'],   # Keywords that define your package best
    install_requires=[            # I get to this in a second
        'certifi',
        'six',
        'python_dateutil',
        'setuptools',
        'urllib3'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Science/Research',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: Other/Proprietary License',   # Again, pick a license
        'Programming Language :: Python :: 3.7',
    ],
    long_description_content_type="text/markdown",
    long_description=long_description,
)


# coding: utf-8

"""
    UniCatDB API

    UniCatDB application API documentation, with examples and live testing.  This API is built in accordance with the **JSON API 1.0 standard**. For general information, see [the documentation](http://jsonapi.org/format/).  **Notes:** * JSON API standard requires use of the JSON API media type (application/vnd.api+json) for exchanging data. Clients must send all JSON API data with the headers `Content-Type: application/vnd.api+json` (POST, PATCH) and `Accept: application/vnd.api+json` (GET, DELETE). * [Relationships](http://jsonapi.org/format/#fetching-relationships) and their [inclusions](http://jsonapi.org/format/#fetching-includes) via the `include` query parameter, as specified by the standard, **are not implemented**, since there are no relationships present in the data model. * The standard does not prescribe any filtering strategies. This API implements two strategies which can be combined: **Basic filtering** based on the used [JSON API library](https://json-api-dotnet.github.io/#/filtering) and **Custom filtering** which allow for any possible query to the MongoDB server and can be extended and customize in the future. For more information about filtering, see the description of the `filter` down bellow. * **Non-standard PATCH behavior:** Sucessfull PATCH reuest always result in HTTP 200 response with the updated resource object, even if the server does not perform any additional modifications. HTTP 204 is never used in PATCH responses.   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from unicatdb.openapi_client.api_client import ApiClient
from unicatdb.openapi_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class SecurityApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_security_authenticate(self, **kwargs):  # noqa: E501
        """Authenticate user based on credentials and obtain JWT token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.api_security_authenticate(async_req=True)
        >>> result = thread.get()

        :param credentials_request_body:
        :type credentials_request_body: CredentialsRequestBody
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuthenticationResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.api_security_authenticate_with_http_info(**kwargs)  # noqa: E501

    def api_security_authenticate_with_http_info(self, **kwargs):  # noqa: E501
        """Authenticate user based on credentials and obtain JWT token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.api_security_authenticate_with_http_info(async_req=True)
        >>> result = thread.get()

        :param credentials_request_body:
        :type credentials_request_body: CredentialsRequestBody
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AuthenticationResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'credentials_request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_security_authenticate" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'credentials_request_body' in local_var_params:
            body_params = local_var_params['credentials_request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501
        
        response_types_map = {
            200: "AuthenticationResponse",
            400: None,
            401: None,
        }

        return self.api_client.call_api(
            '/api/security/authenticate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def api_security_revalidate(self, **kwargs):  # noqa: E501
        """Revalidate existing JWT token of the user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.api_security_revalidate(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuthenticationResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.api_security_revalidate_with_http_info(**kwargs)  # noqa: E501

    def api_security_revalidate_with_http_info(self, **kwargs):  # noqa: E501
        """Revalidate existing JWT token of the user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.api_security_revalidate_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AuthenticationResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_security_revalidate" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'JwtAuth']  # noqa: E501
        
        response_types_map = {
            200: "AuthenticationResponse",
            401: None,
        }

        return self.api_client.call_api(
            '/api/security/revalidate', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def api_security_user_script_credentials(self, **kwargs):  # noqa: E501
        """Get credentials for usage in user scripts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.api_security_user_script_credentials(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserScriptCredentialsResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.api_security_user_script_credentials_with_http_info(**kwargs)  # noqa: E501

    def api_security_user_script_credentials_with_http_info(self, **kwargs):  # noqa: E501
        """Get credentials for usage in user scripts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.api_security_user_script_credentials_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UserScriptCredentialsResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_security_user_script_credentials" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'JwtAuth']  # noqa: E501
        
        response_types_map = {
            200: "UserScriptCredentialsResponse",
            401: None,
        }

        return self.api_client.call_api(
            '/api/security/user-script-credentials', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
